@@ -72,7 +72,7 @@ ProjectTab::ProjectTab(QWidget *parent)
         "If you need more information or documentation, then a visit to "
         "<a href=\"%2\">%2</a> "
         "will provide you with what you need.</html>",
-        QLatin1String("http://community.kde.org/Getinvolved"),
+        QLatin1String("http://community.kde.org/Get_Involved"),
         QLatin1String("http://techbase.kde.org/")), welcomeWidget);
     about->setAlignment(Qt::AlignCenter);
     about->setWordWrap(true);
